==> gcc-fortran-4.0.3.tar.bz2: gcc-4.0.3/libgfortran/intrinsics/ierrno.c <==
/* Implementation of the IERRNO intrinsic.
   Copyright (C) 2005 Free Software Foundation, Inc.
   Contributed by François-Xavier Coudert <coudert@clipper.ens.fr>

This file is part of the GNU Fortran 95 runtime library (libgfortran).

Libgfortran is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

In addition to the permissions in the GNU General Public License, the
Free Software Foundation gives you unlimited permission to link the
compiled version of this file into combinations with other programs,
and to distribute those combinations without any restriction coming
from the use of this file.  (The General Public License restrictions
do apply in other respects; for example, they cover modification of
the file, and distribution when not linked into a combine
executable.)

Libgfortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with libgfortran; see the file COPYING.  If not,
write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "config.h"
#include "libgfortran.h"

#include <errno.h>

#include "../io/io.h"


/* INTEGER FUNCTION IERRNO()  */

extern GFC_INTEGER_4 ierrno_i4 (void);
export_proto(ierrno_i4);

GFC_INTEGER_4
ierrno_i4 (void)
{
  return (GFC_INTEGER_4) errno;
}

extern GFC_INTEGER_8 ierrno_i8 (void);
export_proto(ierrno_i8);

GFC_INTEGER_8
ierrno_i8 (void)
{
  return (GFC_INTEGER_8) errno;
}

==> gcc-fortran-4.2.4.tar.bz2: gcc-4.2.4/libgfortran/intrinsics/ierrno.c <==
/* Implementation of the IERRNO intrinsic.
   Copyright (C) 2005 Free Software Foundation, Inc.
   Contributed by François-Xavier Coudert <coudert@clipper.ens.fr>

This file is part of the GNU Fortran 95 runtime library (libgfortran).

Libgfortran is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

In addition to the permissions in the GNU General Public License, the
Free Software Foundation gives you unlimited permission to link the
compiled version of this file into combinations with other programs,
and to distribute those combinations without any restriction coming
from the use of this file.  (The General Public License restrictions
do apply in other respects; for example, they cover modification of
the file, and distribution when not linked into a combine
executable.)

Libgfortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with libgfortran; see the file COPYING.  If not,
write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.  */

#include "config.h"
#include "libgfortran.h"

#include <errno.h>


/* INTEGER FUNCTION IERRNO()  */

extern GFC_INTEGER_4 ierrno_i4 (void);
export_proto(ierrno_i4);

GFC_INTEGER_4
ierrno_i4 (void)
{
  return (GFC_INTEGER_4) errno;
}

extern GFC_INTEGER_8 ierrno_i8 (void);
export_proto(ierrno_i8);

GFC_INTEGER_8
ierrno_i8 (void)
{
  return (GFC_INTEGER_8) errno;
}
